/*
mkr1000_ledtest_version_2
This is the initial test program for the mkr1000 board from Arduino.
five LEDs can be switched ON and OFF via WiFi commands.
This program is based on the original program described
in chapter 5.5.2 of the "Arduino and Genuino
MKR1000 Development Workshop 2016" from Agus Kurniawan.
However updated with 7 LEDs connected between output pins D1..D7 via 1kOhm resistors and GND.
If you want to know more about the mkr1000 board,
see https://www.arduino.cc/en/Main/ArduinoMKR1000
 
modified and improved  april 2017
by Alex Pikkert
 
Improvements:
. fixed IP address for the mkr1000
. one white LED on port D6 showing "trying to connect"
. one green LED on port D7 showing "connected"
. five ports (D1...D5) that can be switched ON/OFF independent from each other
. automatic reconnection when wiFi goes down and returns
. no connection failures with quick commands
. all C++ commands are removed, only use of standard Arduino commands
*/
 
#include <WiFi101.h>
 
int port1 = 1;
int port2 = 2;
int port3 = 3;
int port4 = 4;
int port5 = 5;
int led1 = 6;//White led (trying to connect to WiFi)
int led2 =7;//Green led (WiFi connected)
int val1 = 0;
int val2 = 0;
int val3 = 0;
int val4 = 0;
int val5 = 0;
 
int portreq = 0;
String req;
String s;
 
// Add here your local WiFi network data:
//*********************************************************
IPAddress ip(xxx,xxx,xxx,xxx);// CHANGE INTO YOUR IP ADDRESS
const char* ssid = "xxxxxxx"; // CHANGE INTO YOUR NETWORK NAME
const char* password = "xxxxxxxxxx"; // CHANGE INTO YOUR SECRET PASSWORD
//*********************************************************
 
int status = WL_IDLE_STATUS;
WiFiServer server(80);
 
void setup() {
Serial.begin(9600);
delay(10);
 
// prepare GPIO pins
pinMode(port1, OUTPUT);
pinMode(port2, OUTPUT);
pinMode(port3, OUTPUT);
pinMode(port4, OUTPUT);
pinMode(port5, OUTPUT);
pinMode(led1, OUTPUT);
pinMode(led2, OUTPUT);
 
digitalWrite(port1, 0);
digitalWrite(port2, 0);
digitalWrite(port3, 0);
digitalWrite(port4, 0);
digitalWrite(port5, 0);
digitalWrite(led1, 0);
digitalWrite(led2, 0);
 
delay(5000);
}
 
void loop() {
// Try to connect to the WiFi network
if (WiFi.status() != WL_CONNECTED)
{ConnectWiFi();}
 
// Wait here until a client has connected
WiFiClient client = server.available();
if (!client) {return;}
 
// if connected, Wait until the client sends some data
Serial.println("new client");
if(!client.available()){delay(100);}
 
// Read the first line of the request
req = client.readStringUntil('\r');
Serial.println(req);
client.flush();
 
// Match the request to switch the leds
if (req.indexOf("/port1/0") != -1)
{val1 = 0;portreq = 1;}
else
if (req.indexOf("/port1/1") != -1)
{val1 = 1;portreq = 1;}
else
if (req.indexOf("/port2/0") != -1)
{val2 = 0;portreq = 2;}
else
if (req.indexOf("/port2/1") != -1)
{val2 = 1;portreq = 2;}
else
if (req.indexOf("/port3/0") != -1)
{val3 = 0;portreq = 3;}
else
if (req.indexOf("/port3/1") != -1)
{val3 = 1;portreq = 3;}
else
if (req.indexOf("/port4/0") != -1)
{val4 = 0;portreq = 4;}
else
if (req.indexOf("/port4/1") != -1)
{val4 = 1;portreq = 4;}
else
if (req.indexOf("/port5/0") != -1)
{val5 = 0;portreq = 5;}
else
if (req.indexOf("/port5/1") != -1)
{val5 = 1;portreq = 5;}
else
{Serial.println("invalid request");
client.stop();
return;
}
 
// Set the output pins according to the request
digitalWrite(port1,val1);
digitalWrite(port2,val2);
digitalWrite(port3,val3);
digitalWrite(port4,val4);
digitalWrite(port5,val5);
client.flush();
 
// Prepare the HTML response
s = "HTTP/1.1 200 OK\r\nContent-Type: text/html\r\n\r\n<!DOCTYPE HTML>\r\n<html>\r\n";
if(portreq==1 && val1==0)
{s += "port1 switched OFF ";}
if(portreq==1 && val1==1)
{s += "port1 switched ON ";}
 
if(portreq==2 && val2==0)
{s += "port2 switched OFF ";}
if(portreq==2 && val2==1)
{s += "port2 switched ON ";}
 
if(portreq==3 && val3==0)
{s += "port3 switched OFF ";}
if(portreq==3 && val3==1)
{s += "port3 switched ON ";}
 
if(portreq==4 && val4==0)
{s += "port4 switched OFF ";}
if(portreq==4 && val4==1)
{s += "port4 switched ON ";}
 
if(portreq==5 && val5==0)
{s += "port5 switched OFF ";}
if(portreq==5 && val5==1)
{s += "port5 switched ON ";}
 
s += "</html>\n";
 
// Send the HML response to the client
client.print(s);
delay(100);
client.stop();
Serial.println("Client disconnected");
}
 
// Subprogram to connect to the WiFi network
void ConnectWiFi(){
Serial.print("Attempting to connect to SSID: ");
Serial.println(ssid);
status = WiFi.begin(ssid, password);
digitalWrite(led2,0);digitalWrite(led1,1);
 
// wait 5 seconds for connection:
delay(5000);
WiFi.config(ip);
Serial.println("");
Serial.println("WiFi connected");
 
// Start the server
server.begin();
Serial.println("Server started");
digitalWrite(led2,1);digitalWrite(led1,0);
 
// Print the IP address
IPAddress ip = WiFi.localIP();
Serial.println(ip);
}
